@@ -8,7 +8,7 @@ my ($dbname, $dbuser, $dbpass, $help);
 GetOptions("name=s" => \$dbname,
            "user=s" => \$dbuser,
            "pass=s" => \$dbpass,
-           "help"   => \$help,)i;
+           "help"   => \$help);
 
 unless (defined($dbname)) {
     print "You must supply a database name with the --name option\n";
